@@ -52,14 +52,17 @@ def _setattr(model, attr, value):
 
 def get_params(model: BaseEstimator):
     r"""
-    Fonction possédant le
+    Fonction possédant le même comportement que la méthode get_params de
+    Scikit-Learn mais ne revoit pas les attribues de classe DDP de Pytorch.
     """
     att_ddp = inspect.signature(DDP.__init__)
     att_mod = inspect.signature(model.__init__)
     parameters = [
         pp
         for pp in att_mod.parameters.values()
-        if pp.name != "self" and pp.kind != pp.VAR_KEYWORD and pp not in att_ddp.parameters.values()
+        if pp.name != "self"
+            and pp.kind != pp.VAR_KEYWORD
+            and pp not in att_ddp.parameters.values()
     ]
     for pp in parameters:
         if pp.king == pp.VAR_POSITIONAL:
@@ -952,9 +955,9 @@ class BaseEnvironnement(BaseEstimator):
             if isinstance(e, KeyboardInterrupt):
                 warn(
                     "\n"
-                    "-------------------------------------\n"
-                    "Fin du trining par KeyboardInterrupt.\n"
-                    "-------------------------------------\n"
+                    "------------------------------------------\n"
+                    "| Fin du training par KeyboardInterrupt. |\n"
+                    "------------------------------------------\n"
                 )
             else:
                 raise e
