@@ -137,7 +137,7 @@ def overload_distributed_data_parallel(model: Module):
             list_inter.append(ii)
     if len(list_inter) > 0:
         warn(
-            f"Les attributs : {', '.join()list_inter} ;\n"
+            f"Les attributs : {', '.join(list_inter)} ;\n"
             f"sont communes à la classe {model.__class__.__name__} "
             "et à la classe DPP de PyTorch. La prioriété est donnée a DDP et "
             "peut ne pas avoir d'impacte sur la suite de l'entrainement. "
